# pytest-codegen
Pytest-codgen will statically analyze your code to create pytest function stubs.

Built with [redbaron](https://redbaron.readthedocs.io/en/latest/), [typer](https://typer.tiangolo.com/) and [jinja2](https://jinja.palletsprojects.com/en/2.11.x/).


## Goal
First working version

### Future Goals
- Create templates for tests
- More customization


## Disclaimer
This tool is currently in pre-alpha/experimental phase. Usable version will be ^0.1.x


## Installation

```
pip install pytest-codegen
```

## Usage

Check the supported commands with
```
pytest-codegen --help
```
or if you are lazy like me
```
ptc --help
```

## Suggestions & Contribution

Every suggestion and contribution is welcome!

Set everything up with [poetry](https://python-poetry.org/) and you are good to go :)
```
pip install poetry
```
```
poetry install
```

## Ressources
- [pytest-codegen on pypi](https://pypi.org/project/pytest-codegen/)
- [redbaron on pypi](https://pypi.org/project/redbaron/)
- [typer on pypi](https://pypi.org/project/typer/)
- [jinja2 on pypi](https://pypi.org/project/Jinja2/)

## License
This project is licensed under the terms of the MIT license.